Index: wp-includes/post-template.php
===================================================================
--- wp-includes/post-template.php	(revision 12633)
+++ wp-includes/post-template.php	(working copy)
@@ -903,7 +903,7 @@
  */
 function the_attachment_link( $id = 0, $fullsize = false, $deprecated = false, $permalink = false ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.5' );
 
 	if ( $fullsize )
 		echo wp_get_attachment_link($id, 'full', $permalink);
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 12633)
+++ wp-includes/post.php	(working copy)
@@ -3582,12 +3582,12 @@
  * @since 2.3.0
  * @access private
  *
- * @param int $deprecated Not Used. Can be set to null.
+ * @param int $deprecated Never used. Can be set to null.
  * @param object $post Object type containing the post information
  */
 function _future_post_hook( $deprecated = '', $post ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.3' );
 	wp_clear_scheduled_hook( 'publish_future_post', array( $post->ID ) );
 	wp_schedule_single_event( strtotime( $post->post_date_gmt. ' GMT' ), 'publish_future_post', array( $post->ID ) );
 }
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 12633)
+++ wp-includes/comment.php	(working copy)
@@ -1513,7 +1513,7 @@
  */
 function discover_pingback_server_uri( $url, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.7' );
 
 	$pingback_str_dquote = 'rel="pingback"';
 	$pingback_str_squote = 'rel=\'pingback\'';
Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 12633)
+++ wp-includes/functions.php	(working copy)
@@ -1207,7 +1207,7 @@
  */
 function wp_get_http( $url, $file_path = false, $deprecated = false ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.7' );
 
 	@set_time_limit( 60 );
 
@@ -1252,7 +1252,7 @@
  */
 function wp_get_http_headers( $url, $deprecated = false ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.7' );
 
 	$response = wp_remote_head( $url );
 
@@ -2190,14 +2190,14 @@
  * @since 2.0.0
  *
  * @param string $name
- * @param null $deprecated Not used. Set to null.
+ * @param null $deprecated Never used. Set to null.
  * @param mixed $bits File content
  * @param string $time Optional. Time formatted in 'yyyy/mm'.
  * @return array
  */
 function wp_upload_bits( $name, $deprecated, $bits, $time = null ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.0' );
 
 	if ( empty( $name ) )
 		return array( 'error' => __( 'Empty filename' ) );
@@ -3051,7 +3051,7 @@
  * For example:
  * <code>
  * if ( !empty($deprecated) )
- * 	_deprecated_argument( __FUNCTION__, '0.0' );
+ * 	_deprecated_argument( __FUNCTION__, '3.0' );
  * </code>
  *
  * There is a hook deprecated_argument_run that will be called that can be used
Index: wp-includes/link-template.php
===================================================================
--- wp-includes/link-template.php	(revision 12633)
+++ wp-includes/link-template.php	(working copy)
@@ -170,7 +170,7 @@
  */
 function post_permalink( $post_id = 0, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '1.3' );
 
 	return get_permalink($post_id);
 }
Index: wp-includes/formatting.php
===================================================================
--- wp-includes/formatting.php	(revision 12633)
+++ wp-includes/formatting.php	(working copy)
@@ -867,7 +867,7 @@
  */
 function convert_chars($content, $deprecated = '') {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '0.71' );
 
 	// Translation of invalid Unicode references range to valid range
 	$wp_htmltranswinuni = array(
Index: wp-includes/author-template.php
===================================================================
--- wp-includes/author-template.php	(revision 12633)
+++ wp-includes/author-template.php	(working copy)
@@ -24,7 +24,7 @@
 	global $authordata;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.1' );
 
 	return apply_filters('the_author', is_object($authordata) ? $authordata->display_name : null);
 }
@@ -49,8 +49,10 @@
  * @return string The author's display name, from get_the_author().
  */
 function the_author( $deprecated = '', $deprecated_echo = true ) {
-	if ( !empty( $deprecated ) || $deprecated_echo !== true )
-		_deprecated_argument( __FUNCTION__, '1.5', $deprecated_echo !== true ? __('Use get_the_author() instead if you do not want the value echoed.') : null );
+	if ( !empty( $deprecated ) )
+		_deprecated_argument( __FUNCTION__, '2.1' );
+	if ( $deprecated_echo !== true )
+		_deprecated_argument( __FUNCTION__, '1.5', __('Use get_the_author() instead if you do not want the value echoed.') );
 	if ( $deprecated_echo )
 		echo get_the_author();
 	return get_the_author();
@@ -184,7 +186,7 @@
  */
 function the_author_posts_link($deprecated = '') {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.1' );
 
 	global $authordata;
 	$link = sprintf(
Index: wp-includes/kses.php
===================================================================
--- wp-includes/kses.php	(revision 12633)
+++ wp-includes/kses.php	(working copy)
@@ -1196,9 +1196,14 @@
 add_action('init', 'kses_init');
 add_action('set_current_user', 'kses_init');
 
+/**
+ * Inline CSS filter
+ *
+ * @since 2.8.1
+ */
 function safecss_filter_attr( $css, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.8.1' ); // Never implemented
 
 	$css = wp_kses_no_null($css);
 	$css = str_replace(array("\n","\r","\t"), '', $css);
Index: wp-includes/widgets.php
===================================================================
--- wp-includes/widgets.php	(revision 12633)
+++ wp-includes/widgets.php	(working copy)
@@ -985,7 +985,7 @@
  */
 function wp_get_sidebars_widgets($deprecated = true) {
 	if ( $deprecated !== true )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '2.8.1' );
 
 	global $wp_registered_widgets, $wp_registered_sidebars, $_wp_sidebars_widgets;

Index: wp-admin/includes/image.php
===================================================================
--- wp-admin/includes/image.php	(revision 12633)
+++ wp-admin/includes/image.php	(working copy)
@@ -17,12 +17,12 @@
  *
  * @param mixed $file Filename of the original image, Or attachment id.
  * @param int $max_side Maximum length of a single side for the thumbnail.
- * @param mixed $deprecated Not used.
+ * @param mixed $deprecated Never used.
  * @return string Thumbnail path on success, Error string on failure.
  */
 function wp_create_thumbnail( $file, $max_side, $deprecated = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '1.2' );
 	$thumbpath = image_resize( $file, $max_side, $max_side );
 	return apply_filters( 'wp_create_thumbnail', $thumbpath );
 }

Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 12633)
+++ wp-includes/comment-template.php	(working copy)
@@ -504,11 +504,13 @@
  * @since 0.71
  *
  * @param string $deprecated Not Used
  * @param bool $deprecated Not Used
  */
-function comments_link( $deprecated = '', $deprecated = '' ) {
+function comments_link( $deprecated = '', $deprecated_2 = '' ) {
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '0.72' );
+	if ( !empty( $deprecated_2 ) )
+		_deprecated_argument( __FUNCTION__, '1.3' );
 	echo get_comments_link();
 }
 
@@ -553,7 +555,7 @@
 	global $id;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '1.3' );
 
 	$number = get_comments_number($id);
 
@@ -504,11 +504,13 @@
  *
  * @param string $deprecated Not Used
- * @param bool $deprecated Not Used
+ * @param bool $deprecated_2 Not Used
  */
Index: wp-admin/includes/meta-boxes.php
===================================================================
--- wp-admin/includes/meta-boxes.php	(revision 12633)
+++ wp-admin/includes/meta-boxes.php	(working copy)
@@ -636,13 +636,13 @@
  *
  * @param string $class
  * @param string $value
  * @param mixed $deprecated Not used.
  */
-function xfn_check($class, $value = '', $deprecated = '') {
+function xfn_check( $class, $value = '', $deprecated = '' ) {
 	global $link;
 
 	if ( !empty( $deprecated ) )
-		_deprecated_argument( __FUNCTION__, '0.0' );
+		_deprecated_argument( __FUNCTION__, '0.0' ); // Never implemented
 
 	$link_rel = isset( $link->link_rel ) ? $link->link_rel : ''; // In PHP 5.3: $link_rel = $link->link_rel ?: '';
 	$rels = preg_split('/\s+/', $link_rel);
@@ -636,13 +636,13 @@
  * @param string $class
  * @param string $value
- * @param mixed $deprecated Not used.
+ * @param mixed $deprecated Never used.
  */